summaryrefslogtreecommitdiff
path: root/lua/init.lua
diff options
context:
space:
mode:
Diffstat (limited to 'lua/init.lua')
-rw-r--r--lua/init.lua37
1 files changed, 20 insertions, 17 deletions
diff --git a/lua/init.lua b/lua/init.lua
index f493729..604fd4d 100644
--- a/lua/init.lua
+++ b/lua/init.lua
@@ -1,9 +1,9 @@
-local function dump(o)
+function Dump(o)
if type(o) == 'table' then
local s = '{ '
for k,v in pairs(o) do
if type(k) ~= 'number' then k = '"'..k..'"' end
- s = s .. '['..k..'] = ' .. dump(v) .. ','
+ s = s .. '['..k..'] = ' .. Dump(v) .. ','
end
return s .. '} '
else
@@ -15,6 +15,7 @@ end
local neotree = require("neo-tree")
neotree.setup({
close_if_last_window = false,
+ enable_refresh_on_write = true,
icon = {
folder_closed = "",
folder_open = "",
@@ -48,13 +49,6 @@ neotree.setup({
hide_dotfiles = false,
}
},
- event_handlers = {
- event = "vim_buffer_changed",
- handler = function(_)
- vim.cmd('Git status')
- end,
- id = "AutoGitStatus",
- }
})
-- LSP
@@ -101,14 +95,23 @@ local lsp_capabilibies = require('cmp_nvim_lsp').default_capabilities(
local servers = mason_lspconfig.get_installed_servers()
local configs_custom = {
lua_ls = {
- diagnostics = {
- -- Get the language server to recognize the `vim` global
- globals = {'vim'},
- },
- workspace = {
- -- Make the server aware of Neovim runtime files
- library = vim.api.nvim_get_runtime_file("", true),
- },
+ settings = {
+ Lua = {
+ runtime = {
+ -- Tell the language server which version of Lua you're using
+ -- (most likely LuaJIT in the case of Neovim)
+ version = 'LuaJIT',
+ },
+ diagnostics = {
+ -- Get the language server to recognize the `vim` global
+ globals = {'vim'},
+ },
+ workspace = {
+ -- Make the server aware of Neovim runtime files
+ library = vim.api.nvim_get_runtime_file("", true),
+ },
+ },
+ }
}
}